==> greengrass-1.93.0-sources.jar: software/amazon/awscdk/services/greengrass/CfnConnectorDefinitionVersionProps.java <==
package software.amazon.awscdk.services.greengrass;

/**
 * Properties for defining a `AWS::Greengrass::ConnectorDefinitionVersion`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:21.619Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.greengrass.$Module.class, fqn = "@aws-cdk/aws-greengrass.CfnConnectorDefinitionVersionProps")
@software.amazon.jsii.Jsii.Proxy(CfnConnectorDefinitionVersionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnConnectorDefinitionVersionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Greengrass::ConnectorDefinitionVersion.ConnectorDefinitionId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getConnectorDefinitionId();

    /**
     * `AWS::Greengrass::ConnectorDefinitionVersion.Connectors`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getConnectors();

    /**
     * @return a {@link Builder} of {@link CfnConnectorDefinitionVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnConnectorDefinitionVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnConnectorDefinitionVersionProps> {
        private java.lang.String connectorDefinitionId;
        private java.lang.Object connectors;

        /**
         * Sets the value of {@link CfnConnectorDefinitionVersionProps#getConnectorDefinitionId}
         * @param connectorDefinitionId `AWS::Greengrass::ConnectorDefinitionVersion.ConnectorDefinitionId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder connectorDefinitionId(java.lang.String connectorDefinitionId) {
            this.connectorDefinitionId = connectorDefinitionId;
            return this;
        }

        /**
         * Sets the value of {@link CfnConnectorDefinitionVersionProps#getConnectors}
         * @param connectors `AWS::Greengrass::ConnectorDefinitionVersion.Connectors`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder connectors(software.amazon.awscdk.core.IResolvable connectors) {
            this.connectors = connectors;
            return this;
        }

        /**
         * Sets the value of {@link CfnConnectorDefinitionVersionProps#getConnectors}
         * @param connectors `AWS::Greengrass::ConnectorDefinitionVersion.Connectors`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder connectors(java.util.List<? extends java.lang.Object> connectors) {
            this.connectors = connectors;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnConnectorDefinitionVersionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnConnectorDefinitionVersionProps build() {
            return new Jsii$Proxy(connectorDefinitionId, connectors);
        }
    }

    /**
     * An implementation for {@link CfnConnectorDefinitionVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnConnectorDefinitionVersionProps {
        private final java.lang.String connectorDefinitionId;
        private final java.lang.Object connectors;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.connectorDefinitionId = software.amazon.jsii.Kernel.get(this, "connectorDefinitionId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.connectors = software.amazon.jsii.Kernel.get(this, "connectors", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String connectorDefinitionId, final java.lang.Object connectors) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.connectorDefinitionId = java.util.Objects.requireNonNull(connectorDefinitionId, "connectorDefinitionId is required");
            this.connectors = java.util.Objects.requireNonNull(connectors, "connectors is required");
        }

        @Override
        public final java.lang.String getConnectorDefinitionId() {
            return this.connectorDefinitionId;
        }

        @Override
        public final java.lang.Object getConnectors() {
            return this.connectors;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("connectorDefinitionId", om.valueToTree(this.getConnectorDefinitionId()));
            data.set("connectors", om.valueToTree(this.getConnectors()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-greengrass.CfnConnectorDefinitionVersionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnConnectorDefinitionVersionProps.Jsii$Proxy that = (CfnConnectorDefinitionVersionProps.Jsii$Proxy) o;

            if (!connectorDefinitionId.equals(that.connectorDefinitionId)) return false;
            return this.connectors.equals(that.connectors);
        }

        @Override
        public final int hashCode() {
            int result = this.connectorDefinitionId.hashCode();
            result = 31 * result + (this.connectors.hashCode());
            return result;
        }
    }
}

==> greengrass-1.182.0-sources.jar: software/amazon/awscdk/services/greengrass/CfnConnectorDefinitionVersionProps.java <==
package software.amazon.awscdk.services.greengrass;

/**
 * Properties for defining a `CfnConnectorDefinitionVersion`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.greengrass.*;
 * Object parameters;
 * CfnConnectorDefinitionVersionProps cfnConnectorDefinitionVersionProps = CfnConnectorDefinitionVersionProps.builder()
 *         .connectorDefinitionId("connectorDefinitionId")
 *         .connectors(List.of(ConnectorProperty.builder()
 *                 .connectorArn("connectorArn")
 *                 .id("id")
 *                 // the properties below are optional
 *                 .parameters(parameters)
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:35.082Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.greengrass.$Module.class, fqn = "@aws-cdk/aws-greengrass.CfnConnectorDefinitionVersionProps")
@software.amazon.jsii.Jsii.Proxy(CfnConnectorDefinitionVersionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnConnectorDefinitionVersionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ID of the connector definition associated with this version.
     * <p>
     * This value is a GUID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getConnectorDefinitionId();

    /**
     * The connectors in this version.
     * <p>
     * Only one instance of a given connector can be added to the connector definition version at a time.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getConnectors();

    /**
     * @return a {@link Builder} of {@link CfnConnectorDefinitionVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnConnectorDefinitionVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnConnectorDefinitionVersionProps> {
        java.lang.String connectorDefinitionId;
        java.lang.Object connectors;

        /**
         * Sets the value of {@link CfnConnectorDefinitionVersionProps#getConnectorDefinitionId}
         * @param connectorDefinitionId The ID of the connector definition associated with this version. This parameter is required.
         *                              This value is a GUID.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder connectorDefinitionId(java.lang.String connectorDefinitionId) {
            this.connectorDefinitionId = connectorDefinitionId;
            return this;
        }

        /**
         * Sets the value of {@link CfnConnectorDefinitionVersionProps#getConnectors}
         * @param connectors The connectors in this version. This parameter is required.
         *                   Only one instance of a given connector can be added to the connector definition version at a time.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder connectors(software.amazon.awscdk.core.IResolvable connectors) {
            this.connectors = connectors;
            return this;
        }

        /**
         * Sets the value of {@link CfnConnectorDefinitionVersionProps#getConnectors}
         * @param connectors The connectors in this version. This parameter is required.
         *                   Only one instance of a given connector can be added to the connector definition version at a time.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder connectors(java.util.List<? extends java.lang.Object> connectors) {
            this.connectors = connectors;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnConnectorDefinitionVersionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnConnectorDefinitionVersionProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnConnectorDefinitionVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnConnectorDefinitionVersionProps {
        private final java.lang.String connectorDefinitionId;
        private final java.lang.Object connectors;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.connectorDefinitionId = software.amazon.jsii.Kernel.get(this, "connectorDefinitionId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.connectors = software.amazon.jsii.Kernel.get(this, "connectors", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.connectorDefinitionId = java.util.Objects.requireNonNull(builder.connectorDefinitionId, "connectorDefinitionId is required");
            this.connectors = java.util.Objects.requireNonNull(builder.connectors, "connectors is required");
        }

        @Override
        public final java.lang.String getConnectorDefinitionId() {
            return this.connectorDefinitionId;
        }

        @Override
        public final java.lang.Object getConnectors() {
            return this.connectors;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("connectorDefinitionId", om.valueToTree(this.getConnectorDefinitionId()));
            data.set("connectors", om.valueToTree(this.getConnectors()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-greengrass.CfnConnectorDefinitionVersionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnConnectorDefinitionVersionProps.Jsii$Proxy that = (CfnConnectorDefinitionVersionProps.Jsii$Proxy) o;

            if (!connectorDefinitionId.equals(that.connectorDefinitionId)) return false;
            return this.connectors.equals(that.connectors);
        }

        @Override
        public final int hashCode() {
            int result = this.connectorDefinitionId.hashCode();
            result = 31 * result + (this.connectors.hashCode());
            return result;
        }
    }
}
